@@ -33,7 +33,7 @@
  */
 
 /*
- * $Id: chash.h,v 1.13 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: chash.h,v 1.15 2006/03/22 08:10:47 hoa Exp $
  */
 
 #ifndef CHASH_H
@@ -44,7 +44,7 @@ extern "C" {
 #endif
 
 #ifndef LIBETPAN_CONFIG_H
-#	include "libetpan-config.h"
+#	include <libetpan/libetpan-config.h>
 #endif
 
 typedef struct {
