@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: connect.c,v 1.13 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: connect.c,v 1.15 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "connect.h"
 
 #include <sys/types.h>
@@ -55,7 +59,7 @@ uint16_t mail_get_service_port(const char * name, char * protocol)
   if (service == NULL)
     return 0;
 
-  return service->s_port;
+  return ntohs(service->s_port);
 }
 
 int mail_tcp_connect(const char * server, uint16_t port)
