@@ -30,22 +30,21 @@
  */
 
 /*
- * $Id: maillock.c,v 1.13 2005/06/01 20:23:15 hoa Exp $
+ * $Id: maillock.c,v 1.14 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "maillock.h"
 
 #include "libetpan-config.h"
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <stdio.h>
@@ -53,8 +52,6 @@
 #include <string.h>
 #ifdef _MSC_VER
 #	include "win_etpan.h"
-#else
-#	include "config.h"
 #endif
 #ifdef HAVE_LIBLOCKFILE
 #include <lockfile.h>
