@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: dbdriver.c,v 1.8 2005/08/15 11:08:40 hoa Exp $
+ * $Id: dbdriver.c,v 1.10 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "dbdriver.h"
 #include "imfcache.h"
 #include "generic_cache.h"
@@ -87,7 +91,7 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_db_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "db",
 
   /* sess_initialize */ initialize,
