@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imapdriver.c,v 1.51 2006/02/15 17:57:14 colinleroy Exp $
+ * $Id: imapdriver.c,v 1.55 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imapdriver.h"
 
 #include "mail.h"
@@ -56,54 +60,54 @@ static int imapdriver_connect_stream(mailsession * session, mailstream * s);
 static int imapdriver_starttls(mailsession * session);
 
 static int imapdriver_login(mailsession * session,
-			    char * userid, char * password);
+			    const char * userid, const char * password);
 
 static int imapdriver_logout(mailsession * session);
 
 static int imapdriver_noop(mailsession * session);
 
-static int imapdriver_build_folder_name(mailsession * session, char * mb,
-					char * name, char ** result);
+static int imapdriver_build_folder_name(mailsession * session, const char * mb,
+					const char * name, char ** result);
 
-static int imapdriver_create_folder(mailsession * session, char * mb);
+static int imapdriver_create_folder(mailsession * session, const char * mb);
 
-static int imapdriver_delete_folder(mailsession * session, char * mb);
+static int imapdriver_delete_folder(mailsession * session, const char * mb);
 
-static int imapdriver_rename_folder(mailsession * session, char * mb,
-				    char * new_name);
+static int imapdriver_rename_folder(mailsession * session, const char * mb,
+				    const char * new_name);
 
 static int imapdriver_check_folder(mailsession * session);
 
-static int imapdriver_examine_folder(mailsession * session, char * mb);
+static int imapdriver_examine_folder(mailsession * session, const char * mb);
 
-static int imapdriver_select_folder(mailsession * session, char * mb);
+static int imapdriver_select_folder(mailsession * session, const char * mb);
 static int imapdriver_expunge_folder(mailsession * session);
 
-static int imapdriver_status_folder(mailsession * session, char * mb,
+static int imapdriver_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int imapdriver_messages_number(mailsession * session, char * mb,
+static int imapdriver_messages_number(mailsession * session, const char * mb,
 				      uint32_t * result);
 
-static int imapdriver_recent_number(mailsession * session, char * mb,
+static int imapdriver_recent_number(mailsession * session, const char * mb,
 				      uint32_t * result);
 
-static int imapdriver_unseen_number(mailsession * session, char * mb,
+static int imapdriver_unseen_number(mailsession * session, const char * mb,
 				      uint32_t * result);
 
-static int imapdriver_list_folders(mailsession * session, char * mb,
+static int imapdriver_list_folders(mailsession * session, const char * mb,
 				    struct mail_list ** result);
-static int imapdriver_lsub_folders(mailsession * session, char * mb,
+static int imapdriver_lsub_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result);
-static int imapdriver_subscribe_folder(mailsession * session, char * mb);
-static int imapdriver_unsubscribe_folder(mailsession * session, char * mb);
+static int imapdriver_subscribe_folder(mailsession * session, const char * mb);
+static int imapdriver_unsubscribe_folder(mailsession * session, const char * mb);
 static int imapdriver_append_message(mailsession * session,
-				     char * message, size_t size);
+				     const char * message, size_t size);
 static int imapdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 static int imapdriver_copy_message(mailsession * session,
-				   uint32_t num, char * mb);
+				   uint32_t num, const char * mb);
 
 static int imapdriver_get_messages_list(mailsession * session,
 					struct mailmessage_list ** result);
@@ -114,7 +118,7 @@ imapdriver_get_envelopes_list(mailsession * session,
 
 
 #if 0
-static int imapdriver_search_messages(mailsession * session, char * charset,
+static int imapdriver_search_messages(mailsession * session, const char * charset,
 				      struct mail_search_key * key,
 				      struct mail_search_result ** result);
 #endif
@@ -134,8 +138,10 @@ static int imapdriver_login_sasl(mailsession * session,
     const char * login, const char * auth_name,
     const char * password, const char * realm);
 
+static int imapdriver_remove_message(mailsession * session, uint32_t num);
+
 static mailsession_driver local_imap_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "imap",
 
   /* sess_initialize */ imapdriver_initialize,
@@ -177,7 +183,7 @@ static mailsession_driver local_imap_session_driver = {
 
   /* sess_get_messages_list */ imapdriver_get_messages_list,
   /* sess_get_envelopes_list */ imapdriver_get_envelopes_list,
-  /* sess_remove_message */ NULL,
+  /* sess_remove_message */ imapdriver_remove_message,
 #if 0
   /* sess_search_messages */ imapdriver_search_messages,
 #endif
@@ -222,7 +228,7 @@ static mailsession_driver local_imap_session_driver = {
 
   .sess_get_messages_list = imapdriver_get_messages_list,
   .sess_get_envelopes_list = imapdriver_get_envelopes_list,
-  .sess_remove_message = NULL,
+  .sess_remove_message = imapdriver_remove_message,
 #if 0
   .sess_search_messages = imapdriver_search_messages,
 #endif
@@ -349,7 +355,7 @@ static int imapdriver_connect_stream(mailsession * session, mailstream * s)
 }
 
 static int imapdriver_login(mailsession * session,
-			    char * userid, char * password)
+			    const char * userid, const char * password)
 {
   int r;
 
@@ -379,8 +385,8 @@ static int imapdriver_noop(mailsession * session)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_build_folder_name(mailsession * session, char * mb,
-					char * name, char ** result)
+static int imapdriver_build_folder_name(mailsession * session, const char * mb,
+					const char * name, char ** result)
 {
   char delimiter[2] = "X";
   char * folder_name;
@@ -416,7 +422,7 @@ static int imapdriver_build_folder_name(mailsession * session, char * mb,
 
 /* folders operations */
 
-static int imapdriver_create_folder(mailsession * session, char * mb)
+static int imapdriver_create_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -425,7 +431,7 @@ static int imapdriver_create_folder(mailsession * session, char * mb)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_delete_folder(mailsession * session, char * mb)
+static int imapdriver_delete_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -434,8 +440,8 @@ static int imapdriver_delete_folder(mailsession * session, char * mb)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_rename_folder(mailsession * session, char * mb,
-				    char * new_name)
+static int imapdriver_rename_folder(mailsession * session, const char * mb,
+				    const char * new_name)
 {
   int r;
 
@@ -456,7 +462,7 @@ static int imapdriver_check_folder(mailsession * session)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_examine_folder(mailsession * session, char * mb)
+static int imapdriver_examine_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -465,7 +471,7 @@ static int imapdriver_examine_folder(mailsession * session, char * mb)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_select_folder(mailsession * session, char * mb)
+static int imapdriver_select_folder(mailsession * session, const char * mb)
 {
   int r;
   char * new_mb;
@@ -511,7 +517,7 @@ static int imapdriver_expunge_folder(mailsession * session)
   return imap_error_to_mail_error(r);
 }
 
-static int status_selected_folder(mailsession * session, char * mb,
+static int status_selected_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -560,7 +566,7 @@ static int status_selected_folder(mailsession * session, char * mb,
   return res;
 }
 
-static int status_unselected_folder(mailsession * session, char * mb,
+static int status_unselected_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -649,7 +655,7 @@ static int status_unselected_folder(mailsession * session, char * mb,
   return res;
 }
 
-static int imapdriver_status_folder(mailsession * session, char * mb,
+static int imapdriver_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -684,7 +690,7 @@ static int imapdriver_status_folder(mailsession * session, char * mb,
 
 /* TODO : more efficient functions */
 
-static int imapdriver_messages_number(mailsession * session, char * mb,
+static int imapdriver_messages_number(mailsession * session, const char * mb,
 				      uint32_t * result)
 {
   uint32_t messages;
@@ -701,7 +707,7 @@ static int imapdriver_messages_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int imapdriver_recent_number(mailsession * session, char * mb,
+static int imapdriver_recent_number(mailsession * session, const char * mb,
 				    uint32_t * result)
 {
   uint32_t messages;
@@ -718,7 +724,7 @@ static int imapdriver_recent_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int imapdriver_unseen_number(mailsession * session, char * mb,
+static int imapdriver_unseen_number(mailsession * session, const char * mb,
 				    uint32_t * result)
 {
   uint32_t messages;
@@ -740,7 +746,7 @@ enum {
 };
 
 static int imapdriver_list_lsub_folders(mailsession * session, int type,
-					char * mb,
+					const char * mb,
 					struct mail_list ** result)
 {
   clist * imap_list;
@@ -787,21 +793,21 @@ static int imapdriver_list_lsub_folders(mailsession * session, int type,
   return res;
 }
 
-static int imapdriver_list_folders(mailsession * session, char * mb,
+static int imapdriver_list_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result)
 {
   return imapdriver_list_lsub_folders(session, IMAP_LIST, mb,
 				      result);
 }
 
-static int imapdriver_lsub_folders(mailsession * session, char * mb,
+static int imapdriver_lsub_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result)
 {
   return imapdriver_list_lsub_folders(session, IMAP_LSUB, mb,
 				      result);
 }
 
-static int imapdriver_subscribe_folder(mailsession * session, char * mb)
+static int imapdriver_subscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -810,7 +816,7 @@ static int imapdriver_subscribe_folder(mailsession * session, char * mb)
   return imap_error_to_mail_error(r);
 }
 
-static int imapdriver_unsubscribe_folder(mailsession * session, char * mb)
+static int imapdriver_unsubscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -822,7 +828,7 @@ static int imapdriver_unsubscribe_folder(mailsession * session, char * mb)
 /* messages operations */
 
 static int imapdriver_append_message(mailsession * session,
-				     char * message, size_t size)
+				     const char * message, size_t size)
 {
   int r;
 
@@ -834,7 +840,7 @@ static int imapdriver_append_message(mailsession * session,
 }
 
 static int imapdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   struct mailimap_flag_list * flag_list;
   int r;
@@ -859,7 +865,7 @@ static int imapdriver_append_message_flags(mailsession * session,
 }
 
 static int imapdriver_copy_message(mailsession * session,
-				   uint32_t num, char * mb)
+				   uint32_t num, const char * mb)
 {
   int r;
   struct mailimap_set * set;
@@ -1083,7 +1089,7 @@ imapdriver_get_envelopes_list(mailsession * session,
 
 
 #if 0
-static int imapdriver_search_messages(mailsession * session, char * charset,
+static int imapdriver_search_messages(mailsession * session, const char * charset,
 				      struct mail_search_key * key,
 				      struct mail_search_result ** result)
 {
@@ -1300,3 +1306,30 @@ static int imapdriver_login_sasl(mailsession * session,
   
   return imap_error_to_mail_error(r);
 }
+
+
+static int imapdriver_remove_message(mailsession * session, uint32_t num) {
+
+  int res;
+  struct mail_flags					*flags = NULL;
+
+  /* protection if SELECT folder not done */
+  if (get_imap_session(session)->imap_selection_info == NULL) {
+    res = MAIL_ERROR_BAD_STATE;
+    goto err;
+  }
+
+  /* Deleted flag */
+  if ((flags = mail_flags_new_empty()) == NULL) { res = MAIL_ERROR_MEMORY; goto err;}
+  flags->fl_flags = MAIL_FLAG_DELETED;
+
+  /* STORE num \Deleted */
+  /* EXPUNGE */
+  if ((res = imap_store_flags(get_imap_session(session), num, num, flags)) == MAILIMAP_NO_ERROR)
+		res = mailimap_expunge(get_imap_session(session));
+  res = imap_error_to_mail_error(res);
+
+err:
+	if (flags != NULL) mail_flags_free( flags);
+	return res;
+}
