@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imapdriver_cached.c,v 1.49 2005/08/15 11:08:40 hoa Exp $
+ * $Id: imapdriver_cached.c,v 1.53 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imapdriver_cached.h"
 
 #include "libetpan-config.h"
@@ -42,7 +46,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <stdlib.h>
@@ -71,46 +75,46 @@ static int imapdriver_cached_connect_stream(mailsession * session,
 static int imapdriver_cached_starttls(mailsession * session);
 
 static int imapdriver_cached_login(mailsession * session,
-				   char * userid, char * password);
+				   const char * userid, const char * password);
 static int imapdriver_cached_logout(mailsession * session);
 static int imapdriver_cached_noop(mailsession * session);
 static int imapdriver_cached_build_folder_name(mailsession * session,
-					       char * mb,
-					       char * name, char ** result);
-static int imapdriver_cached_create_folder(mailsession * session, char * mb);
-static int imapdriver_cached_delete_folder(mailsession * session, char * mb);
-static int imapdriver_cached_rename_folder(mailsession * session, char * mb,
-					   char * new_name);
+					       const char * mb,
+					       const char * name, char ** result);
+static int imapdriver_cached_create_folder(mailsession * session, const char * mb);
+static int imapdriver_cached_delete_folder(mailsession * session, const char * mb);
+static int imapdriver_cached_rename_folder(mailsession * session, const char * mb,
+					   const char * new_name);
 static int imapdriver_cached_check_folder(mailsession * session);
 static int imapdriver_cached_examine_folder(mailsession * session,
-					    char * mb);
-static int imapdriver_cached_select_folder(mailsession * session, char * mb);
+					    const char * mb);
+static int imapdriver_cached_select_folder(mailsession * session, const char * mb);
 static int imapdriver_cached_expunge_folder(mailsession * session);
-static int imapdriver_cached_status_folder(mailsession * session, char * mb,
+static int imapdriver_cached_status_folder(mailsession * session, const char * mb,
 					   uint32_t * result_messages,
 					   uint32_t * result_recent,
 					   uint32_t * result_unseen);
 static int imapdriver_cached_messages_number(mailsession * session,
-					     char * mb,
+					     const char * mb,
 					     uint32_t * result);
-static int imapdriver_cached_recent_number(mailsession * session, char * mb,
+static int imapdriver_cached_recent_number(mailsession * session, const char * mb,
 					   uint32_t * result);
-static int imapdriver_cached_unseen_number(mailsession * session, char * mb,
+static int imapdriver_cached_unseen_number(mailsession * session, const char * mb,
 					   uint32_t * result);
-static int imapdriver_cached_list_folders(mailsession * session, char * mb,
+static int imapdriver_cached_list_folders(mailsession * session, const char * mb,
 					  struct mail_list ** result);
-static int imapdriver_cached_lsub_folders(mailsession * session, char * mb,
+static int imapdriver_cached_lsub_folders(mailsession * session, const char * mb,
 					  struct mail_list ** result);
 static int imapdriver_cached_subscribe_folder(mailsession * session,
-					      char * mb);
+					      const char * mb);
 static int imapdriver_cached_unsubscribe_folder(mailsession * session,
-						char * mb);
+						const char * mb);
 static int imapdriver_cached_append_message(mailsession * session,
-					    char * message, size_t size);
+					    const char * message, size_t size);
 static int imapdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 static int imapdriver_cached_copy_message(mailsession * session,
-					  uint32_t num, char * mb);
+					  uint32_t num, const char * mb);
 
 static int imapdriver_cached_get_messages_list(mailsession * session,
 						struct mailmessage_list **
@@ -123,7 +127,7 @@ static int imapdriver_cached_remove_message(mailsession * session,
 
 #if 0
 static int imapdriver_cached_search_messages(mailsession * session,
-					      char * charset,
+					      const char * charset,
 					      struct mail_search_key * key,
 					      struct mail_search_result **
 					      result);
@@ -145,7 +149,7 @@ static int imapdriver_cached_login_sasl(mailsession * session,
     const char * password, const char * realm);
 
 static mailsession_driver local_imap_cached_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "imap-cached",
 
   /* sess_initialize */ imapdriver_cached_initialize,
@@ -286,6 +290,7 @@ static int imapdriver_cached_initialize(mailsession * session)
   data->imap_uid_list = carray_new(128);
   if (data->imap_uid_list == NULL)
     goto free_session;
+  data->imap_uidvalidity = 0;
   
   session->sess_data = data;
   
@@ -320,8 +325,10 @@ static int update_uid_cache(mailsession * session,
   int r;
   struct imap_cached_session_state_data * data;
   int res;
-
+  mailimap * imap;
+  
   data = get_cached_data(session);
+  imap = get_imap_session(session);
   
   /* free all UID cache */
   for(i = 0 ; i < carray_count(data->imap_uid_list) ; i ++) {
@@ -330,30 +337,40 @@ static int update_uid_cache(mailsession * session,
     cache_item = carray_get(data->imap_uid_list, i);
     free(cache_item);
   }
-
-  /* build UID cache */
-  r = carray_set_size(data->imap_uid_list,
-      carray_count(env_list->msg_tab));
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto err;
-  }
   
-  for(i = 0 ; i < carray_count(env_list->msg_tab) ; i ++) {
-    struct uid_cache_item * cache_item;
-    mailmessage * msg;
-    
-    cache_item = malloc(sizeof(* cache_item));
-    if (cache_item == NULL) {
+  if (env_list == NULL) {
+    r = carray_set_size(data->imap_uid_list, 0);
+    if (r < 0) {
       res = MAIL_ERROR_MEMORY;
       goto err;
     }
-    msg = carray_get(env_list->msg_tab, i);
-    cache_item->uid = msg->msg_index;
-    cache_item->size = msg->msg_size;
-    
-    carray_set(data->imap_uid_list, i, cache_item);
   }
+  else {
+    /* build UID cache */
+    r = carray_set_size(data->imap_uid_list,
+        carray_count(env_list->msg_tab));
+    if (r < 0) {
+      res = MAIL_ERROR_MEMORY;
+      goto err;
+    }
+  
+    for(i = 0 ; i < carray_count(env_list->msg_tab) ; i ++) {
+      struct uid_cache_item * cache_item;
+      mailmessage * msg;
+    
+      cache_item = malloc(sizeof(* cache_item));
+      if (cache_item == NULL) {
+        res = MAIL_ERROR_MEMORY;
+        goto err;
+      }
+      msg = carray_get(env_list->msg_tab, i);
+      cache_item->uid = msg->msg_index;
+      cache_item->size = msg->msg_size;
+    
+      carray_set(data->imap_uid_list, i, cache_item);
+    }
+  }
+  data->imap_uidvalidity = imap->imap_selection_info->sel_uidvalidity;
   
   return MAIL_NO_ERROR;
 
@@ -501,7 +518,7 @@ static int imapdriver_cached_starttls(mailsession * session)
 }
 
 static int imapdriver_cached_login(mailsession * session,
-				   char * userid, char * password)
+				   const char * userid, const char * password)
 {
   int r;
   
@@ -543,8 +560,8 @@ static int imapdriver_cached_noop(mailsession * session)
 }
 
 static int imapdriver_cached_build_folder_name(mailsession * session,
-					       char * mb,
-					       char * name, char ** result)
+					       const char * mb,
+					       const char * name, char ** result)
 {
   int r;
   
@@ -556,7 +573,7 @@ static int imapdriver_cached_build_folder_name(mailsession * session,
   return r;
 }
 
-static int imapdriver_cached_create_folder(mailsession * session, char * mb)
+static int imapdriver_cached_create_folder(mailsession * session, const char * mb)
 {
   int r;
   
@@ -567,7 +584,7 @@ static int imapdriver_cached_create_folder(mailsession * session, char * mb)
   return r;
 }
 
-static int imapdriver_cached_delete_folder(mailsession * session, char * mb)
+static int imapdriver_cached_delete_folder(mailsession * session, const char * mb)
 {
   int r;
   
@@ -578,8 +595,8 @@ static int imapdriver_cached_delete_folder(mailsession * session, char * mb)
   return r;
 }
 
-static int imapdriver_cached_rename_folder(mailsession * session, char * mb,
-					   char * new_name)
+static int imapdriver_cached_rename_folder(mailsession * session, const char * mb,
+					   const char * new_name)
 {
   int r;
   
@@ -602,7 +619,7 @@ static int imapdriver_cached_check_folder(mailsession * session)
 }
 
 static int imapdriver_cached_examine_folder(mailsession * session,
-					    char * mb)
+					    const char * mb)
 {
   int r;
  
@@ -682,7 +699,7 @@ static int get_cache_folder(mailsession * session, char ** result)
   return res;
 }
 
-static int imapdriver_cached_select_folder(mailsession * session, char * mb)
+static int imapdriver_cached_select_folder(mailsession * session, const char * mb)
 {
   int r;
   char * quoted_mb;
@@ -730,7 +747,7 @@ static int imapdriver_cached_expunge_folder(mailsession * session)
   return r;
 }
 
-static int imapdriver_cached_status_folder(mailsession * session, char * mb,
+static int imapdriver_cached_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -745,7 +762,7 @@ static int imapdriver_cached_status_folder(mailsession * session, char * mb,
 }
 
 static int imapdriver_cached_messages_number(mailsession * session,
-					     char * mb,
+					     const char * mb,
 					     uint32_t * result)
 {
   int r;
@@ -757,7 +774,7 @@ static int imapdriver_cached_messages_number(mailsession * session,
   return r;
 }
 
-static int imapdriver_cached_recent_number(mailsession * session, char * mb,
+static int imapdriver_cached_recent_number(mailsession * session, const char * mb,
 					   uint32_t * result)
 {
   int r;
@@ -769,7 +786,7 @@ static int imapdriver_cached_recent_number(mailsession * session, char * mb,
   return r;
 }
 
-static int imapdriver_cached_unseen_number(mailsession * session, char * mb,
+static int imapdriver_cached_unseen_number(mailsession * session, const char * mb,
 					   uint32_t * result)
 {
   int r;
@@ -781,7 +798,7 @@ static int imapdriver_cached_unseen_number(mailsession * session, char * mb,
   return r;
 }
 
-static int imapdriver_cached_list_folders(mailsession * session, char * mb,
+static int imapdriver_cached_list_folders(mailsession * session, const char * mb,
 					  struct mail_list ** result)
 {
   int r;
@@ -793,7 +810,7 @@ static int imapdriver_cached_list_folders(mailsession * session, char * mb,
   return r;
 }
 
-static int imapdriver_cached_lsub_folders(mailsession * session, char * mb,
+static int imapdriver_cached_lsub_folders(mailsession * session, const char * mb,
 					  struct mail_list ** result)
 {
   int r;
@@ -806,7 +823,7 @@ static int imapdriver_cached_lsub_folders(mailsession * session, char * mb,
 }
 
 static int imapdriver_cached_subscribe_folder(mailsession * session,
-					      char * mb)
+					      const char * mb)
 {
   int r;
   
@@ -818,7 +835,7 @@ static int imapdriver_cached_subscribe_folder(mailsession * session,
 }
 
 static int imapdriver_cached_unsubscribe_folder(mailsession * session,
-						char * mb)
+						const char * mb)
 {
   int r;
 
@@ -830,7 +847,7 @@ static int imapdriver_cached_unsubscribe_folder(mailsession * session,
 }
 
 static int imapdriver_cached_append_message(mailsession * session,
-					    char * message, size_t size)
+					    const char * message, size_t size)
 {
   int r;
   
@@ -842,7 +859,7 @@ static int imapdriver_cached_append_message(mailsession * session,
 }
 
 static int imapdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   int r;
   
@@ -855,7 +872,7 @@ static int imapdriver_cached_append_message_flags(mailsession * session,
 }
 
 static int imapdriver_cached_copy_message(mailsession * session,
-					  uint32_t num, char * mb)
+					  uint32_t num, const char * mb)
 {
   int r;
 
@@ -878,6 +895,153 @@ static int cmp_uid(uint32_t ** pa, uint32_t ** pb)
 }
 
 
+static void get_uid_from_filename(const char * filename)
+{
+  char * p;
+  
+  p = strstr(filename, "-part");
+  if (p != NULL)
+    * p = 0;
+  p = strstr(filename, "-envelope");
+  if (p != NULL)
+    * p = 0;
+  p = strstr(filename, "-rfc822");
+  if (p != NULL)
+    * p = 0;
+}  
+
+#define ENV_NAME "env.db"
+
+static int boostrap_cache(mailsession * session)
+{
+  struct mail_cache_db * cache_db;
+  char filename[PATH_MAX];
+  mailimap * imap;
+  struct imap_cached_session_state_data * data;
+  MMAPString * mmapstr;
+  int r;
+  int res;
+  chashiter * iter;
+  chash * keys;
+  chash * keys_uid;
+  
+  data = get_cached_data(session);
+  imap = get_imap_session(session);
+  
+  if (data->imap_quoted_mb == NULL) {
+    res = MAIL_ERROR_BAD_STATE;
+    goto err;
+  }
+  
+  mmapstr = mmap_string_new("");
+  if (mmapstr == NULL) {
+    res = MAIL_ERROR_MEMORY;
+    goto err;
+  }
+
+  snprintf(filename, PATH_MAX, "%s/%s", data->imap_quoted_mb, ENV_NAME);
+  
+  r = mail_cache_db_open_lock(filename, &cache_db);
+  if (r < 0) {
+    res = MAIL_ERROR_MEMORY;
+    goto free_mmapstr;
+  }
+  
+  keys = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
+  if (keys == NULL) {
+    res = MAIL_ERROR_MEMORY;
+    goto close_db;
+  }
+  
+  r = mail_cache_db_get_keys(cache_db, keys);
+  if (r < 0) {
+    res = MAIL_ERROR_MEMORY;
+    goto free_keys;
+  }
+  
+  keys_uid = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
+  if (keys_uid == NULL) {
+    res = MAIL_ERROR_MEMORY;
+    goto free_keys;
+  }
+  
+  for(iter = chash_begin(keys) ; iter != NULL ; iter = chash_next(keys, iter)) {
+    chashdatum key;
+    chashdatum value;
+    char msg_uid[PATH_MAX];
+    
+    chash_key(iter, &key);
+    if (key.len >= sizeof(msg_uid)) {
+      strncpy(msg_uid, key.data, sizeof(msg_uid));
+      msg_uid[sizeof(msg_uid) - 1] = 0;
+    }
+    else {
+      strncpy(msg_uid, key.data, key.len);
+      msg_uid[key.len] = 0;
+    }
+    
+    get_uid_from_filename(msg_uid);
+    key.data = msg_uid;
+    key.len = strlen(msg_uid) + 1;
+    value.data = NULL;
+    value.len = 0;
+    chash_set(keys_uid, &key, &value, NULL);
+  }
+  
+  for(iter = chash_begin(keys_uid) ; iter != NULL ; iter = chash_next(keys_uid, iter)) {
+    chashdatum key;
+    uint32_t uidvalidity;
+    uint32_t index;
+    char * uid;
+    char * p1, * p2;
+    struct uid_cache_item * cache_item;
+    
+    chash_key(iter, &key);
+    uid = key.data;
+    
+    uidvalidity = strtoul(uid, &p1, 10);
+    if (p1 == uid || * p1 != '-')
+      continue;
+    
+    data->imap_uidvalidity = uidvalidity;
+    
+    p1++;
+    index = strtoul(p1, &p2, 10);
+    if (p2 == p1 || * p2 != '\0')
+      continue;
+    
+    cache_item = malloc(sizeof(* cache_item));
+    if (cache_item == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto free_keys;
+    }
+    
+    cache_item->uid = index;
+    cache_item->size = 0;
+    
+    carray_add(data->imap_uid_list, cache_item, NULL);
+  }
+  
+  chash_free(keys_uid);
+  chash_free(keys);
+  
+  mail_cache_db_close_unlock(filename, cache_db);
+  
+  return MAIL_NO_ERROR;
+  
+/* free_keys_uid:*/
+  chash_free(keys_uid);
+ free_keys:
+  chash_free(keys);
+ close_db:
+  mail_cache_db_close_unlock(filename, cache_db);
+ free_mmapstr:
+  mmap_string_free(mmapstr);
+ err:
+  return res;
+}
+
+
 static int imapdriver_cached_get_messages_list(mailsession * session,
 					       struct mailmessage_list **
 					       result)
@@ -905,6 +1069,14 @@ static int imapdriver_cached_get_messages_list(mailsession * session,
   uid_max = 0;
 
 #ifdef CACHE_MESSAGE_LIST
+  if (data->imap_uidvalidity == 0) {
+    boostrap_cache(session);
+  }
+  
+  if (imap->imap_selection_info->sel_uidvalidity != data->imap_uidvalidity) {
+    update_uid_cache(session, NULL);
+  }
+  
   /* get UID max */
   uid_max = 0;
   for(i = 0 ; i < carray_count(data->imap_uid_list) ; i ++) {
@@ -1212,23 +1384,6 @@ static int get_flags_list(mailsession * session,
 }
 
 
-#define ENV_NAME "env.db"
-
-static void get_uid_from_filename(char * filename)
-{
-  char * p;
-  
-  p = strstr(filename, "-part");
-  if (p != NULL)
-    * p = 0;
-  p = strstr(filename, "-envelope");
-  if (p != NULL)
-    * p = 0;
-  p = strstr(filename, "-rfc822");
-  if (p != NULL)
-    * p = 0;
-}  
-
 static int
 imapdriver_cached_get_envelopes_list(mailsession * session,
 				     struct mailmessage_list * env_list)
