@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: nntpdriver_tools.c,v 1.18 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: nntpdriver_tools.c,v 1.20 2006/06/07 15:10:00 smarinier Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "nntpdriver_tools.h"
 
 #include "mail.h"
@@ -48,7 +52,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <string.h>
@@ -406,7 +410,7 @@ nntpdriver_write_cached_flags(struct mail_cache_db * cache_db,
 }
 
 
-int nntpdriver_select_folder(mailsession * session, char * mb)
+int nntpdriver_select_folder(mailsession * session, const char * mb)
 {
   int r;
   struct newsnntp_group_info * info;
