@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_types.h,v 1.8 2005/08/15 11:08:40 hoa Exp $
+ * $Id: pop3driver_types.h,v 1.9 2006/05/22 13:39:40 hoa Exp $
  */
 
 #ifndef POP3DRIVER_TYPES_H
@@ -52,13 +52,13 @@ extern "C" {
 /* POP3 driver for session */
 
 enum {
-  POP3DRIVER_SET_AUTH_TYPE = 1,
+  POP3DRIVER_SET_AUTH_TYPE = 1
 };
 
 enum {
   POP3DRIVER_AUTH_TYPE_PLAIN = 0,
   POP3DRIVER_AUTH_TYPE_APOP,
-  POP3DRIVER_AUTH_TYPE_TRY_APOP,
+  POP3DRIVER_AUTH_TYPE_TRY_APOP
 };
 
 struct pop3_session_state_data {
@@ -73,7 +73,7 @@ enum {
   POP3DRIVER_CACHED_SET_AUTH_TYPE = 1,
   /* cache specific */
   POP3DRIVER_CACHED_SET_CACHE_DIRECTORY,
-  POP3DRIVER_CACHED_SET_FLAGS_DIRECTORY,
+  POP3DRIVER_CACHED_SET_FLAGS_DIRECTORY
 };
 
 struct pop3_cached_session_state_data {
@@ -155,7 +155,7 @@ enum {
   POP3_AUTH_TYPE_SASL_PLAIN,        /* SASL plain */
   POP3_AUTH_TYPE_SASL_SCRAM_MD5,    /* SASL SCRAM MD5 */
   POP3_AUTH_TYPE_SASL_GSSAPI,       /* SASL GSSAPI */
-  POP3_AUTH_TYPE_SASL_DIGEST_MD5,   /* SASL digest MD5 */
+  POP3_AUTH_TYPE_SASL_DIGEST_MD5    /* SASL digest MD5 */
 };
 
 #ifdef __cplusplus
