@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver_types.h,v 1.43 2005/08/15 11:08:40 hoa Exp $
+ * $Id: maildriver_types.h,v 1.47 2006/06/26 11:50:27 hoa Exp $
  */
 
 #ifndef MAILDRIVER_TYPES_H
@@ -38,7 +38,9 @@
 #define MAILDRIVER_TYPES_H
 
 #ifndef _MSC_VER
-#	include <inttypes.h>
+#	ifdef HAVE_INTTYPES_H
+#		include <inttypes.h>
+#	endif
 #	include <sys/types.h>
 #endif
 
@@ -107,7 +109,7 @@ enum {
   MAIL_FLAG_DELETED   = 1 << 3,
   MAIL_FLAG_ANSWERED  = 1 << 4,
   MAIL_FLAG_FORWARDED = 1 << 5,
-  MAIL_FLAG_CANCELLED = 1 << 6,
+  MAIL_FLAG_CANCELLED = 1 << 6
 };
 
 /*
@@ -479,55 +481,55 @@ struct mailsession_driver {
       int id, void * value);
 
   int (* sess_connect_stream)(mailsession * session, mailstream * s);
-  int (* sess_connect_path)(mailsession * session, char * path);
+  int (* sess_connect_path)(mailsession * session, const char * path);
 
   int (* sess_starttls)(mailsession * session);
 
-  int (* sess_login)(mailsession * session, char * userid, char * password);
+  int (* sess_login)(mailsession * session, const char * userid, const char * password);
   int (* sess_logout)(mailsession * session);
   int (* sess_noop)(mailsession * session);
 
   /* folders operations */
 
-  int (* sess_build_folder_name)(mailsession * session, char * mb,
-      char * name, char ** result);
+  int (* sess_build_folder_name)(mailsession * session, const char * mb,
+      const char * name, char ** result);
 
-  int (* sess_create_folder)(mailsession * session, char * mb);
-  int (* sess_delete_folder)(mailsession * session, char * mb);
-  int (* sess_rename_folder)(mailsession * session, char * mb,
-      char * new_name);
+  int (* sess_create_folder)(mailsession * session, const char * mb);
+  int (* sess_delete_folder)(mailsession * session, const char * mb);
+  int (* sess_rename_folder)(mailsession * session, const char * mb,
+      const char * new_name);
   int (* sess_check_folder)(mailsession * session);
-  int (* sess_examine_folder)(mailsession * session, char * mb);
-  int (* sess_select_folder)(mailsession * session, char * mb);
+  int (* sess_examine_folder)(mailsession * session, const char * mb);
+  int (* sess_select_folder)(mailsession * session, const char * mb);
   int (* sess_expunge_folder)(mailsession * session);
-  int (* sess_status_folder)(mailsession * session, char * mb,
+  int (* sess_status_folder)(mailsession * session, const char * mb,
       uint32_t * result_num, uint32_t * result_recent,
       uint32_t * result_unseen);
-  int (* sess_messages_number)(mailsession * session, char * mb,
+  int (* sess_messages_number)(mailsession * session, const char * mb,
       uint32_t * result);
-  int (* sess_recent_number)(mailsession * session, char * mb,
+  int (* sess_recent_number)(mailsession * session, const char * mb,
       uint32_t * result);
-  int (* sess_unseen_number)(mailsession * session, char * mb,
+  int (* sess_unseen_number)(mailsession * session, const char * mb,
       uint32_t * result);
 
-  int (* sess_list_folders)(mailsession * session, char * mb,
+  int (* sess_list_folders)(mailsession * session, const char * mb,
       struct mail_list ** result);
-  int (* sess_lsub_folders)(mailsession * session, char * mb,
+  int (* sess_lsub_folders)(mailsession * session, const char * mb,
       struct mail_list ** result);
 
-  int (* sess_subscribe_folder)(mailsession * session, char * mb);
-  int (* sess_unsubscribe_folder)(mailsession * session, char * mb);
+  int (* sess_subscribe_folder)(mailsession * session, const char * mb);
+  int (* sess_unsubscribe_folder)(mailsession * session, const char * mb);
 
   /* messages operations */
 
   int (* sess_append_message)(mailsession * session,
-      char * message, size_t size);
+      const char * message, size_t size);
   int (* sess_append_message_flags)(mailsession * session,
-      char * message, size_t size, struct mail_flags * flags);
+      const char * message, size_t size, struct mail_flags * flags);
   int (* sess_copy_message)(mailsession * session,
-      uint32_t num, char * mb);
+      uint32_t num, const char * mb);
   int (* sess_move_message)(mailsession * session,
-      uint32_t num, char * mb);
+      uint32_t num, const char * mb);
 
   int (* sess_get_message)(mailsession * session,
       uint32_t num, mailmessage ** result);
@@ -541,7 +543,7 @@ struct mailsession_driver {
       struct mailmessage_list * env_list);
   int (* sess_remove_message)(mailsession * session, uint32_t num);
 #if 0
-  int (* sess_search_messages)(mailsession * session, char * charset,
+  int (* sess_search_messages)(mailsession * session, const char * charset,
       struct mail_search_key * key,
       struct mail_search_result ** result);
 #endif
@@ -811,6 +813,13 @@ struct generic_message_t {
 LIBETPAN_EXPORT
 const char * maildriver_strerror(int err);
 
+/* basic malloc / free functions to be compliant with the library allocations */
+LIBETPAN_EXPORT
+void *libetpan_malloc(size_t length);
+
+LIBETPAN_EXPORT
+void libetpan_free(void* data);
+
 #ifdef __cplusplus
 }
 #endif
