@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailstorage_tools.c,v 1.18 2005/08/15 11:08:40 hoa Exp $
+ * $Id: mailstorage_tools.c,v 1.19 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailstorage_tools.h"
 
 #include "libetpan-config.h"
