@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailthread.c,v 1.27 2005/06/01 12:22:01 smarinier Exp $
+ * $Id: mailthread.c,v 1.28 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailthread.h"
 #include "mailthread_types.h"
 
