@@ -30,11 +30,16 @@
  */
 
 /*
- * $Id: mailprivacy_smime.c,v 1.12 2005/12/07 14:57:57 hoa Exp $
+ * $Id: mailprivacy_smime.c,v 1.14 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailprivacy_smime.h"
 #include <string.h>
+#include <pthread.h>
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -155,7 +160,7 @@ enum {
   ERROR_SMIME_CHECK,
   ERROR_SMIME_COMMAND,
   ERROR_SMIME_FILE,
-  ERROR_SMIME_NOPASSPHRASE,
+  ERROR_SMIME_NOPASSPHRASE
 };
 
 #define BUF_SIZE 1024
@@ -582,7 +587,7 @@ smime_verify(struct mailprivacy * privacy,
   
   unlink(description_filename);
   unlink(stripped_filename);
-  // unlink(smime_filename);
+  /* unlink(smime_filename); */
   
   * result = multipart;
   
@@ -810,8 +815,8 @@ static int smime_sign(struct mailprivacy * privacy,
   strip_mime_headers(signed_mime);
   
   unlink(description_filename);
-  // unlink(signature_filename);
-  // unlink(signed_filename);
+  /* unlink(signature_filename); */
+  /* unlink(signed_filename); */
   
   * result = signed_mime;
   
@@ -1148,7 +1153,7 @@ static int smime_sign_encrypt(struct mailprivacy * privacy,
 }
 
 
-#if defined (_MSC_VER) || defined ( __SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_encryption smime_encryption_tab[] = {
   /* S/MIME signed part */
   {
@@ -1200,7 +1205,7 @@ static struct mailprivacy_encryption smime_encryption_tab[] = {
 };
 #endif
 
-#if defined (_MSC_VER) || defined ( __SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_protocol smime_protocol = {
   /* name */ "smime",
   /* description */ "S/MIME",
