@@ -30,17 +30,17 @@
  */
 
 /*
- * $Id: mailimap.c,v 1.31 2005/07/16 17:55:56 hoa Exp $
+ * $Id: mailimap.c,v 1.34 2006/05/22 13:39:40 hoa Exp $
  */
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
 #include "mailimap.h"
 #include "mailimap_parser.h"
 #include "mailimap_sender.h"
+#include "mailimap_extension.h"
 #include "mail.h"
 
 #include <stdio.h>
@@ -115,13 +115,6 @@
 http://www.ietf.org/ids.by.wg/imapext.html
 */
 
-static char * read_line(mailimap * session);
-
-static int send_current_tag(mailimap * session);
-
-static int parse_response(mailimap * session,
-			   struct mailimap_response ** result);
-
 static int parse_greeting(mailimap * session,
 			   struct mailimap_greeting ** result);
 
@@ -343,6 +336,16 @@ static void mailbox_data_store(mailimap * session,
       session->imap_selection_info->sel_recent =
         mb_data->mbd_data.mbd_recent;
     break;
+  case MAILIMAP_MAILBOX_DATA_EXTENSION_DATA:
+    if (session->imap_response_info) {
+      r = clist_append(session->imap_response_info->rsp_extension_list,
+          mb_data->mbd_data.mbd_extension);
+      if (r == 0)
+	mb_data->mbd_data.mbd_extension = NULL;
+      else {
+	/* TODO must handle error case */	
+      }
+    }
   }
 }
 
@@ -413,6 +416,9 @@ cont_req_or_resp_data_store(mailimap * session,
 	resp_data->rsp_data.rsp_capability_data = NULL;
       }
       break;
+    case MAILIMAP_RESP_DATA_TYPE_EXTENSION_DATA:
+      mailimap_extension_data_store(session, &(resp_data->rsp_data.rsp_extension_data));
+      break;
     }
   }
 }
@@ -499,6 +505,7 @@ static void greeting_store(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_connect(mailimap * session, mailstream * s)
 {
   struct mailimap_greeting * greeting;
@@ -551,6 +558,7 @@ int mailimap_connect(mailimap * session, mailstream * s)
 
 
 
+LIBETPAN_EXPORT
 int mailimap_append(mailimap * session, const char * mailbox,
     struct mailimap_flag_list * flag_list,
     struct mailimap_date_time * date_time,
@@ -634,6 +642,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_noop(mailimap * session)
 {
   struct mailimap_response * response;
@@ -675,6 +684,7 @@ int mailimap_noop(mailimap * session)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_logout(mailimap * session)
 {
   struct mailimap_response * response;
@@ -824,6 +834,7 @@ err:
   return NULL;
 }
 
+LIBETPAN_EXPORT
 int mailimap_capability(mailimap * session,
 				struct mailimap_capability_data ** result)
 {
@@ -874,6 +885,7 @@ int mailimap_capability(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_check(mailimap * session)
 {
   struct mailimap_response * response;
@@ -918,6 +930,7 @@ int mailimap_check(mailimap * session)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_close(mailimap * session)
 {
   struct mailimap_response * response;
@@ -967,6 +980,7 @@ int mailimap_close(mailimap * session)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_expunge(mailimap * session)
 {
   struct mailimap_response * response;
@@ -1011,6 +1025,7 @@ int mailimap_expunge(mailimap * session)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_copy(mailimap * session, struct mailimap_set * set,
     const char * mb)
 {
@@ -1056,6 +1071,7 @@ int mailimap_copy(mailimap * session, struct mailimap_set * set,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_uid_copy(mailimap * session, struct mailimap_set * set,
     const char * mb)
 {
@@ -1101,6 +1117,7 @@ int mailimap_uid_copy(mailimap * session, struct mailimap_set * set,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_create(mailimap * session, const char * mb)
 {
   struct mailimap_response * response;
@@ -1147,6 +1164,7 @@ int mailimap_create(mailimap * session, const char * mb)
 }
 
 
+LIBETPAN_EXPORT
 int mailimap_delete(mailimap * session, const char * mb)
 {
   struct mailimap_response * response;
@@ -1192,6 +1210,7 @@ int mailimap_delete(mailimap * session, const char * mb)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_examine(mailimap * session, const char * mb)
 {
   struct mailimap_response * response;
@@ -1245,6 +1264,7 @@ int mailimap_examine(mailimap * session, const char * mb)
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_fetch(mailimap * session, struct mailimap_set * set,
 	       struct mailimap_fetch_type * fetch_type, clist ** result)
@@ -1294,12 +1314,14 @@ mailimap_fetch(mailimap * session, struct mailimap_set * set,
   }
 }
 
+LIBETPAN_EXPORT
 void mailimap_fetch_list_free(clist * fetch_list)
 {
   clist_foreach(fetch_list, (clist_func) mailimap_msg_att_free, NULL);
   clist_free(fetch_list);
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_uid_fetch(mailimap * session,
 		   struct mailimap_set * set,
@@ -1351,6 +1373,7 @@ mailimap_uid_fetch(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_list(mailimap * session, const char * mb,
 		   const char * list_mb, clist ** result)
 {
@@ -1400,6 +1423,7 @@ int mailimap_list(mailimap * session, const char * mb,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_login(mailimap * session,
     const char * userid, const char * password)
 {
@@ -1509,6 +1533,7 @@ static int sasl_getrealm(void * context, int id,
 }
 #endif
 
+LIBETPAN_EXPORT
 int mailimap_authenticate(mailimap * session, const char * auth_type,
     const char * server_fqdn,
     const char * local_ip_port,
@@ -1749,6 +1774,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
 }
 
 
+LIBETPAN_EXPORT
 int mailimap_lsub(mailimap * session, const char * mb,
     const char * list_mb, clist ** result)
 {
@@ -1798,12 +1824,14 @@ int mailimap_lsub(mailimap * session, const char * mb,
   }
 }
 
+LIBETPAN_EXPORT
 void mailimap_list_result_free(clist * list)
 {
   clist_foreach(list, (clist_func) mailimap_mailbox_list_free, NULL);
   clist_free(list);
 }
 
+LIBETPAN_EXPORT
 int mailimap_rename(mailimap * session,
     const char * mb, const char * new_name)
 {
@@ -1850,6 +1878,7 @@ int mailimap_rename(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_search(mailimap * session, const char * charset,
     struct mailimap_search_key * key, clist ** result)
@@ -1899,6 +1928,7 @@ mailimap_search(mailimap * session, const char * charset,
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_uid_search(mailimap * session, const char * charset,
     struct mailimap_search_key * key, clist ** result)
@@ -1948,12 +1978,14 @@ mailimap_uid_search(mailimap * session, const char * charset,
   }
 }
 
+LIBETPAN_EXPORT
 void mailimap_search_result_free(clist * search_result)
 {
   clist_foreach(search_result, (clist_func) free, NULL);
   clist_free(search_result);
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_select(mailimap * session, const char * mb)
 {
@@ -2008,6 +2040,7 @@ mailimap_select(mailimap * session, const char * mb)
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_status(mailimap * session, const char * mb,
     struct mailimap_status_att_list * status_att_list,
@@ -2060,6 +2093,7 @@ mailimap_status(mailimap * session, const char * mb,
 }
 
 
+LIBETPAN_EXPORT
 int
 mailimap_store(mailimap * session,
 	       struct mailimap_set * set,
@@ -2107,6 +2141,7 @@ mailimap_store(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailimap_uid_store(mailimap * session,
 		   struct mailimap_set * set,
@@ -2154,6 +2189,7 @@ mailimap_uid_store(mailimap * session,
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_subscribe(mailimap * session, const char * mb)
 {
   struct mailimap_response * response;
@@ -2199,6 +2235,7 @@ int mailimap_subscribe(mailimap * session, const char * mb)
   }
 }
 
+LIBETPAN_EXPORT
 int mailimap_unsubscribe(mailimap * session, const char * mb)
 {
   struct mailimap_response * response;
@@ -2245,6 +2282,7 @@ int mailimap_unsubscribe(mailimap * session, const char * mb)
 }
 
 
+LIBETPAN_EXPORT
 int mailimap_starttls(mailimap * session)
 {
   struct mailimap_response * response;
@@ -2288,12 +2326,12 @@ int mailimap_starttls(mailimap * session)
 
 
 
-static char * read_line(mailimap * session)
+char * read_line(mailimap * session)
 {
   return mailstream_read_line(session->imap_stream, session->imap_stream_buffer);
 }
 
-static int send_current_tag(mailimap * session)
+int send_current_tag(mailimap * session)
 {
   char tag_str[15];
   int r;
@@ -2312,7 +2350,7 @@ static int send_current_tag(mailimap * session)
   return MAILIMAP_NO_ERROR;
 }
 
-static int parse_response(mailimap * session,
+int parse_response(mailimap * session,
 	 			struct mailimap_response ** result)
 {
   size_t index;
@@ -2407,6 +2445,7 @@ static int parse_greeting(mailimap * session,
 }
 
 
+LIBETPAN_EXPORT
 mailimap * mailimap_new(size_t imap_progr_rate,
     progress_function * imap_progr_fun)
 {
@@ -2452,6 +2491,7 @@ mailimap * mailimap_new(size_t imap_progr_rate,
   return NULL;
 }
 
+LIBETPAN_EXPORT
 void mailimap_free(mailimap * session)
 {
 #ifdef USE_SASL
