@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap.h,v 1.16 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailimap.h,v 1.17 2006/04/15 15:32:26 hoa Exp $
  */
 
 #ifndef MAILIMAP_H
@@ -67,6 +67,7 @@ extern "C" {
   MAILIMAP_NO_ERROR_AUTHENTICATED is returned.
 */
 
+LIBETPAN_EXPORT
 int mailimap_connect(mailimap * session, mailstream * s);
 
 /*
@@ -86,6 +87,7 @@ int mailimap_connect(mailimap * session, mailstream * s);
     MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_append(mailimap * session, const char * mailbox,
     struct mailimap_flag_list * flag_list,
     struct mailimap_date_time * date_time,
@@ -103,6 +105,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
      MAILIMAP_NO_ERROR_XXX codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_noop(mailimap * session);
 
 /*
@@ -117,6 +120,7 @@ int mailimap_noop(mailimap * session);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_logout(mailimap * session);
 
 /*
@@ -133,6 +137,7 @@ int mailimap_logout(mailimap * session);
      MAILIMAP_NO_ERROR codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_capability(mailimap * session,
 			struct mailimap_capability_data ** result);
 
@@ -148,6 +153,7 @@ int mailimap_capability(mailimap * session,
      MAILIMAP_NO_ERROR codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_check(mailimap * session);
 
 /*
@@ -162,6 +168,7 @@ int mailimap_check(mailimap * session);
      MAILIMAP_NO_ERROR codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_close(mailimap * session);
 
 /*
@@ -176,6 +183,7 @@ int mailimap_close(mailimap * session);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_expunge(mailimap * session);
 
 /*
@@ -192,6 +200,7 @@ int mailimap_expunge(mailimap * session);
      MAILIMAP_NO_ERROR codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_copy(mailimap * session, struct mailimap_set * set,
     const char * mb);
 
@@ -209,6 +218,7 @@ int mailimap_copy(mailimap * session, struct mailimap_set * set,
    MAILIMAP_NO_ERROR codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_uid_copy(mailimap * session,
     struct mailimap_set * set, const char * mb);
 
@@ -224,6 +234,7 @@ int mailimap_uid_copy(mailimap * session,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_create(mailimap * session, const char * mb);
 
 /*
@@ -238,6 +249,7 @@ int mailimap_create(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_delete(mailimap * session, const char * mb);
 
 /*
@@ -252,6 +264,7 @@ int mailimap_delete(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_examine(mailimap * session, const char * mb);
 
 /*
@@ -271,6 +284,7 @@ int mailimap_examine(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_fetch(mailimap * session, struct mailimap_set * set,
 	       struct mailimap_fetch_type * fetch_type, clist ** result);
@@ -292,6 +306,7 @@ mailimap_fetch(mailimap * session, struct mailimap_set * set,
      MAILIMAP_NO_ERROR codes
 */
    
+LIBETPAN_EXPORT
 int
 mailimap_uid_fetch(mailimap * session,
 		   struct mailimap_set * set,
@@ -306,6 +321,7 @@ mailimap_uid_fetch(mailimap * session,
      (struct mailimap_msg_att *) elements to free.
 */
 
+LIBETPAN_EXPORT
 void mailimap_fetch_list_free(clist * fetch_list);
 
 /*
@@ -325,6 +341,7 @@ void mailimap_fetch_list_free(clist * fetch_list);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_list(mailimap * session, const char * mb,
     const char * list_mb, clist ** result);
 
@@ -341,6 +358,7 @@ int mailimap_list(mailimap * session, const char * mb,
     MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_login(mailimap * session,
     const char * userid, const char * password);
 
@@ -351,6 +369,7 @@ int mailimap_login(mailimap * session,
    TODO : documentation
 */
 
+LIBETPAN_EXPORT
 int mailimap_authenticate(mailimap * session, const char * auth_type,
     const char * server_fqdn,
     const char * local_ip_port,
@@ -376,6 +395,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_lsub(mailimap * session, const char * mb,
 		  const char * list_mb, clist ** result);
 
@@ -387,6 +407,7 @@ int mailimap_lsub(mailimap * session, const char * mb,
    @param list  This is the clist to free.
 */
 
+LIBETPAN_EXPORT
 void mailimap_list_result_free(clist * list);
 
 /*
@@ -402,6 +423,7 @@ void mailimap_list_result_free(clist * list);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_rename(mailimap * session,
     const char * mb, const char * new_name);
 
@@ -422,6 +444,7 @@ int mailimap_rename(mailimap * session,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_search(mailimap * session, const char * charset,
     struct mailimap_search_key * key, clist ** result);
@@ -444,6 +467,7 @@ mailimap_search(mailimap * session, const char * charset,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_uid_search(mailimap * session, const char * charset,
     struct mailimap_search_key * key, clist ** result);
@@ -457,6 +481,7 @@ mailimap_uid_search(mailimap * session, const char * charset,
      by mailimap_uid_search() or mailimap_search()
 */
 
+LIBETPAN_EXPORT
 void mailimap_search_result_free(clist * search_result);
 
 /*
@@ -472,6 +497,7 @@ void mailimap_search_result_free(clist * search_result);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_select(mailimap * session, const char * mb);
 
@@ -489,6 +515,7 @@ mailimap_select(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_status(mailimap * session, const char * mb,
 		struct mailimap_status_att_list * status_att_list,
@@ -509,6 +536,7 @@ mailimap_status(mailimap * session, const char * mb,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_store(mailimap * session,
 	       struct mailimap_set * set,
@@ -529,6 +557,7 @@ mailimap_store(mailimap * session,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int
 mailimap_uid_store(mailimap * session,
     struct mailimap_set * set,
@@ -547,6 +576,7 @@ mailimap_uid_store(mailimap * session,
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_subscribe(mailimap * session, const char * mb);
 
 /*
@@ -562,6 +592,7 @@ int mailimap_subscribe(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR codes
 */
 
+LIBETPAN_EXPORT
 int mailimap_unsubscribe(mailimap * session, const char * mb);
 
 /*
@@ -576,6 +607,7 @@ int mailimap_unsubscribe(mailimap * session, const char * mb);
      MAILIMAP_NO_ERROR_XXX codes
  */
 
+LIBETPAN_EXPORT
 int mailimap_starttls(mailimap * session);
 
 /*
@@ -592,6 +624,7 @@ int mailimap_starttls(mailimap * session);
    @return an IMAP session is returned.
  */
 
+LIBETPAN_EXPORT
 mailimap * mailimap_new(size_t imap_progr_rate,
     progress_function * imap_progr_fun);
 
@@ -604,8 +637,16 @@ mailimap * mailimap_new(size_t imap_progr_rate,
    @param session   IMAP session
  */
 
+LIBETPAN_EXPORT
 void mailimap_free(mailimap * session);
 
+int send_current_tag(mailimap * session);
+
+char * read_line(mailimap * session);
+
+int parse_response(mailimap * session,
+			   struct mailimap_response ** result);
+
 #ifdef __cplusplus
 }
 #endif
