@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailimap_sender.c,v 1.25 2005/07/18 14:02:33 hoa Exp $
+ * $Id: mailimap_sender.c,v 1.28 2006/05/22 13:39:41 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailstream.h"
 #include "mailimap_keywords.h"
 #include "mailimap_sender.h"
@@ -122,20 +126,12 @@ static int
 mailimap_header_list_send(mailstream * fd,
 			  struct mailimap_header_list * header_list);
 
-static int
-mailimap_list_mailbox_send(mailstream * fd, const char * pattern);
-
-
-static int mailimap_mailbox_send(mailstream * fd, const char * mb);
-
 static int mailimap_number_send(mailstream * fd, uint32_t number);
 
 static int mailimap_password_send(mailstream * fd, const char * pass);
 
 static int mailimap_quoted_char_send(mailstream * fd, char ch);
 
-static int mailimap_quoted_send(mailstream * fd, const char * quoted);
-
 
 static int mailimap_search_key_send(mailstream * fd,
 				    struct mailimap_search_key * key);
@@ -227,7 +223,7 @@ int mailimap_token_send(mailstream * fd, const char * atom)
   return mailimap_sized_token_send(fd, atom, strlen(atom));
 }
 
-static int mailimap_char_send(mailstream * fd, char ch)
+int mailimap_char_send(mailstream * fd, char ch)
 {
   if (mailstream_write(fd, &ch, 1) == -1)
     return MAILIMAP_ERROR_STREAM;
@@ -235,8 +231,6 @@ static int mailimap_char_send(mailstream * fd, char ch)
   return MAILIMAP_NO_ERROR;
 }
 
-typedef int mailimap_struct_sender(mailstream * fd, void * data);
-
 static int
 mailimap_struct_list_send(mailstream * fd, clist * list,
 			  char symbol,
@@ -272,7 +266,7 @@ mailimap_struct_list_send(mailstream * fd, clist * list,
 }
 				   
 
-static int
+int
 mailimap_struct_spaced_list_send(mailstream * fd, clist * list,
 				 mailimap_struct_sender * sender)
 {
@@ -411,7 +405,7 @@ static int is_atom(const char * str)
   return 1;
 }
 
-static int mailimap_astring_send(mailstream * fd, const char * astring)
+int mailimap_astring_send(mailstream * fd, const char * astring)
 {
   /*
     workaround for buggy Courier-IMAP that does not accept 
@@ -1434,7 +1428,7 @@ int mailimap_list_send(mailstream * fd,
 =>   list-mailbox    = 1*list-char / string
 */
 
-static int
+int
 mailimap_list_mailbox_send(mailstream * fd, const char * pattern)
 {
   return mailimap_quoted_send(fd, pattern);
@@ -1595,7 +1589,7 @@ int mailimap_lsub_send(mailstream * fd,
                        ; semantic details of mailbox names.
 */
 
-static int mailimap_mailbox_send(mailstream * fd, const char * mb)
+int mailimap_mailbox_send(mailstream * fd, const char * mb)
 {
   return mailimap_astring_send(fd, mb);
 }
@@ -1723,7 +1717,7 @@ static int mailimap_quoted_char_send(mailstream * fd, char ch)
     return mailimap_char_send(fd, ch);
 }
 
-static int mailimap_quoted_send(mailstream * fd, const char * quoted)
+int mailimap_quoted_send(mailstream * fd, const char * quoted)
 {
   const char * pos;
   int r;
