@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_sender.h,v 1.11 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailimap_sender.h,v 1.13 2006/04/25 07:41:50 lemma Exp $
  */
 
 #ifndef MAILIMAP_SENDER_H
@@ -159,6 +159,23 @@ int mailimap_starttls_send(mailstream * fd);
 
 int mailimap_token_send(mailstream * fd, const char * atom);
 
+int mailimap_quoted_send(mailstream * fd, const char * quoted);
+
+typedef int mailimap_struct_sender(mailstream * fd, void * data);
+
+int
+mailimap_struct_spaced_list_send(mailstream * fd, clist * list,
+				 mailimap_struct_sender * sender);
+
+int
+mailimap_list_mailbox_send(mailstream * fd, const char * pattern);
+
+int mailimap_char_send(mailstream * fd, char ch);
+
+int mailimap_mailbox_send(mailstream * fd, const char * mb);
+
+int mailimap_astring_send(mailstream * fd, const char * astring);
+
 #ifdef __cplusplus
 }
 #endif
