@@ -30,12 +30,17 @@
  */
 
 /*
- * $Id: mailimap_types.c,v 1.21 2004/11/21 21:53:36 hoa Exp $
+ * $Id: mailimap_types.c,v 1.24 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailimap_types.h"
 #include "mmapstring.h"
 #include "mail.h"
+#include "mailimap_extension.h"
 
 #include <stdlib.h>
 
@@ -1339,7 +1344,8 @@ mailimap_mailbox_data_new(int mbd_type, struct mailimap_flag_list * mbd_flags,
     clist * mbd_search,
     struct mailimap_mailbox_data_status * mbd_status,
     uint32_t mbd_exists,
-    uint32_t mbd_recent)
+    uint32_t mbd_recent,
+    struct mailimap_extension_data * mbd_extension)
 {
   struct mailimap_mailbox_data * data;
 
@@ -1370,6 +1376,9 @@ mailimap_mailbox_data_new(int mbd_type, struct mailimap_flag_list * mbd_flags,
   case MAILIMAP_MAILBOX_DATA_RECENT:
     data->mbd_data.mbd_recent = mbd_recent;
     break;
+  case MAILIMAP_MAILBOX_DATA_EXTENSION_DATA:
+    data->mbd_data.mbd_extension = mbd_extension;
+    break;
   }
   
   return data;
@@ -1399,6 +1408,10 @@ mailimap_mailbox_data_free(struct mailimap_mailbox_data * mb_data)
     if (mb_data->mbd_data.mbd_status != NULL)
       mailimap_mailbox_data_status_free(mb_data->mbd_data.mbd_status);
     break;
+  case MAILIMAP_MAILBOX_DATA_EXTENSION_DATA:
+    if (mb_data->mbd_data.mbd_extension != NULL)
+      mailimap_extension_data_free(mb_data->mbd_data.mbd_extension);
+    break;
   }
   free(mb_data);
 }
@@ -1922,7 +1935,8 @@ mailimap_response_data_new(int rsp_type,
     struct mailimap_resp_cond_bye * rsp_bye,
     struct mailimap_mailbox_data * rsp_mailbox_data,
     struct mailimap_message_data * rsp_message_data,
-    struct mailimap_capability_data * rsp_capability_data)
+    struct mailimap_capability_data * rsp_capability_data,
+    struct mailimap_extension_data * rsp_extension_data)
 {
   struct mailimap_response_data * resp_data;
 
@@ -1947,6 +1961,9 @@ mailimap_response_data_new(int rsp_type,
   case MAILIMAP_RESP_DATA_TYPE_CAPABILITY_DATA:
     resp_data->rsp_data.rsp_capability_data = rsp_capability_data;
     break;
+  case MAILIMAP_RESP_DATA_TYPE_EXTENSION_DATA:
+    resp_data->rsp_data.rsp_extension_data = rsp_extension_data;
+    break;
   }
   
   return resp_data;
@@ -1976,6 +1993,10 @@ mailimap_response_data_free(struct mailimap_response_data * resp_data)
     if (resp_data->rsp_data.rsp_capability_data != NULL)
       mailimap_capability_data_free(resp_data->rsp_data.rsp_capability_data);
     break;
+  case MAILIMAP_RESP_DATA_TYPE_EXTENSION_DATA:
+    if (resp_data->rsp_data.rsp_extension_data != NULL)
+      mailimap_extension_data_free(resp_data->rsp_data.rsp_extension_data);
+    break;
   }
   free(resp_data);
 }
@@ -2171,7 +2192,8 @@ mailimap_resp_text_code_new(int rc_type, clist * rc_badcharset,
     struct mailimap_capability_data * rc_cap_data,
     clist * rc_perm_flags,
     uint32_t rc_uidnext, uint32_t rc_uidvalidity,
-    uint32_t rc_first_unseen, char * rc_atom, char * rc_atom_value)
+    uint32_t rc_first_unseen, char * rc_atom, char * rc_atom_value,
+    struct mailimap_extension_data * rc_ext_data)
 {
   struct mailimap_resp_text_code * resp_text_code;
 
@@ -2203,6 +2225,9 @@ mailimap_resp_text_code_new(int rc_type, clist * rc_badcharset,
     resp_text_code->rc_data.rc_atom.atom_name = rc_atom;
     resp_text_code->rc_data.rc_atom.atom_value = rc_atom_value;
     break;
+  case MAILIMAP_RESP_TEXT_CODE_EXTENSION:
+    resp_text_code->rc_data.rc_ext_data = rc_ext_data;
+    break;
   }
 
   return resp_text_code;
@@ -2237,6 +2262,10 @@ mailimap_resp_text_code_free(struct mailimap_resp_text_code * resp_text_code)
     if (resp_text_code->rc_data.rc_atom.atom_value != NULL)
       mailimap_custom_string_free(resp_text_code->rc_data.rc_atom.atom_value);
     break;
+  case MAILIMAP_RESP_TEXT_CODE_EXTENSION:
+    if (resp_text_code->rc_data.rc_ext_data != NULL)
+      mailimap_extension_data_free(resp_text_code->rc_data.rc_ext_data);
+    break;
   }
   free(resp_text_code);
 }
@@ -2888,6 +2917,7 @@ mailimap_response_info_new(void)
   resp_info->rsp_badcharset = NULL;
   resp_info->rsp_trycreate = FALSE;
   resp_info->rsp_mailbox_list = clist_new();
+  resp_info->rsp_extension_list = clist_new();
   if (resp_info->rsp_mailbox_list == NULL)
     goto free;
   resp_info->rsp_mailbox_lsub = clist_new();
@@ -2937,6 +2967,11 @@ mailimap_response_info_free(struct mailimap_response_info * resp_info)
         (clist_func) mailimap_mailbox_list_free, NULL);
     clist_free(resp_info->rsp_mailbox_list);
   }
+  if (resp_info->rsp_extension_list != NULL) {
+    clist_foreach(resp_info->rsp_extension_list,
+      (clist_func) mailimap_extension_data_free, NULL);
+    clist_free(resp_info->rsp_extension_list);
+  }
   if (resp_info->rsp_mailbox_lsub != NULL) {
     clist_foreach(resp_info->rsp_mailbox_lsub,
         (clist_func) mailimap_mailbox_list_free, NULL);
