@@ -29,17 +29,16 @@
  * SUCH DAMAGE.
  */
 
-#include "mailimf_types_helper.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mailimf_types_helper.h"
+
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #ifdef _MSC_VER
@@ -49,7 +48,7 @@
 #include "mailimf.h"
 
 struct mailimf_mailbox_list *
-mailimf_mailbox_list_new_empty()
+mailimf_mailbox_list_new_empty(void)
 {
   clist * list;
   struct mailimf_mailbox_list * mb_list;
@@ -136,7 +135,7 @@ int mailimf_mailbox_list_add_mb(struct mailimf_mailbox_list * mailbox_list,
 
 
 struct mailimf_address_list *
-mailimf_address_list_new_empty()
+mailimf_address_list_new_empty(void)
 {
   clist * list;
   struct mailimf_address_list * addr_list;
@@ -232,7 +231,7 @@ int mailimf_address_list_add_mb(struct mailimf_address_list * address_list,
 
 #if 0
 struct mailimf_resent_fields_list *
-mailimf_resent_fields_list_new_empty()
+mailimf_resent_fields_list_new_empty(void)
 {
   clist * list;
   struct mailimf_resent_fields_list * rf_list;
@@ -1318,7 +1317,7 @@ struct mailimf_date_time * mailimf_get_current_date(void)
 
 
 /* mkgmtime.c - make time corresponding to a GMT timeval struct
- $Id: mailimf_types_helper.c,v 1.16 2005/06/01 20:23:16 hoa Exp $
+ $Id: mailimf_types_helper.c,v 1.17 2006/05/22 13:39:42 hoa Exp $
  
  * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
  *
