@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: maildir.c,v 1.14 2005/12/20 17:56:11 hoa Exp $
+ * $Id: maildir.c,v 1.16 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "maildir.h"
 
 #include <string.h>
@@ -525,7 +529,7 @@ int maildir_message_add_uid(struct maildir * md,
   }
   
   mapping = mmap(NULL, size, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
-  if (mapping == MAP_FAILED) {
+  if (mapping == (char *)MAP_FAILED) {
     res = MAILDIR_ERROR_FILE;
     goto close;
   }
@@ -627,7 +631,7 @@ int maildir_message_add_file_uid(struct maildir * md, int fd,
     return MAILDIR_ERROR_FILE;
   
   message = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (message == MAP_FAILED)
+  if (message == (char *)MAP_FAILED)
     return MAILDIR_ERROR_FILE;
   
   r = maildir_message_add_uid(md, message, buf.st_size, uid, max_uid_len);
