@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_decode.c,v 1.26 2005/06/01 16:04:46 hoa Exp $
+ * $Id: mailmime_decode.c,v 1.28 2006/06/26 11:50:27 hoa Exp $
  */
 
 /*
@@ -38,13 +38,17 @@
              Message Header Extensions for Non-ASCII Text
 */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime_decode.h"
 
 #include <ctype.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 #include <string.h>
@@ -92,7 +96,7 @@ mailmime_encoded_word_parse(const char * message, size_t length,
 enum {
   TYPE_ERROR,
   TYPE_WORD,
-  TYPE_ENCODED_WORD,
+  TYPE_ENCODED_WORD
 };
 
 LIBETPAN_EXPORT
