@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.25 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailpop3.c,v 1.26 2006/05/22 13:39:42 hoa Exp $
  */
 
 /*
@@ -42,6 +42,10 @@
 
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailpop3.h"
 #include <stdio.h>
 #include <string.h>
@@ -49,11 +53,6 @@
 #include "mail.h"
 #include <stdlib.h>
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef USE_SASL
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
