@@ -32,12 +32,11 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.24 2006/01/04 11:08:35 hoa Exp $
+ * $Id: mailsmtp.c,v 1.25 2006/05/22 13:39:42 hoa Exp $
  */
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
 #include "mailsmtp.h"
@@ -45,12 +44,12 @@
 #include "base64.h"
 #include "mail.h"
 
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
 #include <string.h>
 #include <stdlib.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <stdio.h>
@@ -474,7 +473,7 @@ int mailesmtp_mail(mailsmtp * session,
   char command[SMTP_STRING_SIZE];
   char *body = "";
 
-#if notyet
+#ifdef notyet
   /* TODO: figure out a way for the user to explicity enable this or not */
   if (session->esmtp & MAILSMTP_ESMTP_8BITMIME)
     body = " BODY=8BITMIME";
