@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_types.h,v 1.13 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailsmtp_types.h,v 1.14 2006/05/22 13:39:43 hoa Exp $
  */
 
 #ifndef MAILSMTP_TYPES_H
@@ -79,7 +79,7 @@ enum {
   MAILSMTP_AUTH_CRAM_MD5 = 2,
   MAILSMTP_AUTH_PLAIN = 4,
   MAILSMTP_AUTH_LOGIN = 8,
-  MAILSMTP_AUTH_DIGEST_MD5 = 16,
+  MAILSMTP_AUTH_DIGEST_MD5 = 16
 };
 
 enum {
@@ -89,7 +89,7 @@ enum {
   MAILSMTP_ESMTP_SIZE = 8,
   MAILSMTP_ESMTP_ETRN = 16,
   MAILSMTP_ESMTP_STARTTLS = 32,
-  MAILSMTP_ESMTP_DSN = 64,
+  MAILSMTP_ESMTP_DSN = 64
 };
   
 struct mailsmtp {
